#[non_exhaustive]pub struct RegisteredUserConsoleFeatureConfigurations {
pub state_persistence: Option<StatePersistenceConfigurations>,
pub shared_view: Option<SharedViewConfigurations>,
pub amazon_q_in_quick_sight: Option<AmazonQInQuickSightConsoleConfigurations>,
pub schedules: Option<SchedulesConfigurations>,
pub recent_snapshots: Option<RecentSnapshotsConfigurations>,
pub threshold_alerts: Option<ThresholdAlertsConfigurations>,
}Expand description
The feature configurations of an embedded Amazon Quick Sight console.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state_persistence: Option<StatePersistenceConfigurations>The state persistence configurations of an embedded Amazon Quick Sight console.
The shared view settings of an embedded dashboard.
amazon_q_in_quick_sight: Option<AmazonQInQuickSightConsoleConfigurations>The Amazon Q configurations of an embedded Amazon Quick Sight console.
schedules: Option<SchedulesConfigurations>The schedules configuration for an embedded Quick Sight dashboard.
recent_snapshots: Option<RecentSnapshotsConfigurations>The recent snapshots configuration for an embedded Quick Sight dashboard.
threshold_alerts: Option<ThresholdAlertsConfigurations>The threshold alerts configuration for an embedded Quick Sight dashboard.
Implementations
Sourceimpl RegisteredUserConsoleFeatureConfigurations
impl RegisteredUserConsoleFeatureConfigurations
Sourcepub fn state_persistence(&self) -> Option<&StatePersistenceConfigurations>
pub fn state_persistence(&self) -> Option<&StatePersistenceConfigurations>
The state persistence configurations of an embedded Amazon Quick Sight console.
The shared view settings of an embedded dashboard.
Sourcepub fn amazon_q_in_quick_sight(
&self,
) -> Option<&AmazonQInQuickSightConsoleConfigurations>
pub fn amazon_q_in_quick_sight( &self, ) -> Option<&AmazonQInQuickSightConsoleConfigurations>
The Amazon Q configurations of an embedded Amazon Quick Sight console.
Sourcepub fn schedules(&self) -> Option<&SchedulesConfigurations>
pub fn schedules(&self) -> Option<&SchedulesConfigurations>
The schedules configuration for an embedded Quick Sight dashboard.
Sourcepub fn recent_snapshots(&self) -> Option<&RecentSnapshotsConfigurations>
pub fn recent_snapshots(&self) -> Option<&RecentSnapshotsConfigurations>
The recent snapshots configuration for an embedded Quick Sight dashboard.
Sourcepub fn threshold_alerts(&self) -> Option<&ThresholdAlertsConfigurations>
pub fn threshold_alerts(&self) -> Option<&ThresholdAlertsConfigurations>
The threshold alerts configuration for an embedded Quick Sight dashboard.
Sourceimpl RegisteredUserConsoleFeatureConfigurations
impl RegisteredUserConsoleFeatureConfigurations
Sourcepub fn builder() -> RegisteredUserConsoleFeatureConfigurationsBuilder
pub fn builder() -> RegisteredUserConsoleFeatureConfigurationsBuilder
Creates a new builder-style object to manufacture RegisteredUserConsoleFeatureConfigurations.