#[non_exhaustive]pub struct RegisteredUserDashboardVisualEmbeddingConfiguration {
pub initial_dashboard_visual_id: Option<DashboardVisualId>,
}Expand description
The experience that you are embedding. You can use this object to generate a url that embeds a visual into your application.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.initial_dashboard_visual_id: Option<DashboardVisualId>The visual ID for the visual that you want the user to embed. This ID is included in the output URL. When the URL in response is accessed, Amazon Quick Sight renders this visual.
The Amazon Resource Name (ARN) of the dashboard that the visual belongs to must be included in the AuthorizedResourceArns parameter. Otherwise, the request will fail with InvalidParameterValueException.
Implementations
Sourceimpl RegisteredUserDashboardVisualEmbeddingConfiguration
impl RegisteredUserDashboardVisualEmbeddingConfiguration
Sourcepub fn initial_dashboard_visual_id(&self) -> Option<&DashboardVisualId>
pub fn initial_dashboard_visual_id(&self) -> Option<&DashboardVisualId>
The visual ID for the visual that you want the user to embed. This ID is included in the output URL. When the URL in response is accessed, Amazon Quick Sight renders this visual.
The Amazon Resource Name (ARN) of the dashboard that the visual belongs to must be included in the AuthorizedResourceArns parameter. Otherwise, the request will fail with InvalidParameterValueException.
Sourceimpl RegisteredUserDashboardVisualEmbeddingConfiguration
impl RegisteredUserDashboardVisualEmbeddingConfiguration
Sourcepub fn builder() -> RegisteredUserDashboardVisualEmbeddingConfigurationBuilder
pub fn builder() -> RegisteredUserDashboardVisualEmbeddingConfigurationBuilder
Creates a new builder-style object to manufacture RegisteredUserDashboardVisualEmbeddingConfiguration.