#[non_exhaustive]pub struct RegisteredUserQuickSightConsoleEmbeddingConfiguration {
pub initial_path: Option<String>,
pub feature_configurations: Option<RegisteredUserConsoleFeatureConfigurations>,
}Expand description
Information about the Amazon Quick Sight console that you want to embed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.initial_path: Option<String>The initial URL path for the Amazon Quick Sight console. InitialPath is required.
The entry point URL is constrained to the following paths:
-
/start -
/start/analyses -
/start/dashboards -
/start/favorites -
/dashboards/DashboardId. DashboardId is the actual ID key from the Amazon Quick Sight console URL of the dashboard. -
/analyses/AnalysisId. AnalysisId is the actual ID key from the Amazon Quick Sight console URL of the analysis.
feature_configurations: Option<RegisteredUserConsoleFeatureConfigurations>The embedding configuration of an embedded Amazon Quick Sight console.
Implementations
Sourceimpl RegisteredUserQuickSightConsoleEmbeddingConfiguration
impl RegisteredUserQuickSightConsoleEmbeddingConfiguration
Sourcepub fn initial_path(&self) -> Option<&str>
pub fn initial_path(&self) -> Option<&str>
The initial URL path for the Amazon Quick Sight console. InitialPath is required.
The entry point URL is constrained to the following paths:
-
/start -
/start/analyses -
/start/dashboards -
/start/favorites -
/dashboards/DashboardId. DashboardId is the actual ID key from the Amazon Quick Sight console URL of the dashboard. -
/analyses/AnalysisId. AnalysisId is the actual ID key from the Amazon Quick Sight console URL of the analysis.
Sourcepub fn feature_configurations(
&self,
) -> Option<&RegisteredUserConsoleFeatureConfigurations>
pub fn feature_configurations( &self, ) -> Option<&RegisteredUserConsoleFeatureConfigurations>
The embedding configuration of an embedded Amazon Quick Sight console.
Sourceimpl RegisteredUserQuickSightConsoleEmbeddingConfiguration
impl RegisteredUserQuickSightConsoleEmbeddingConfiguration
Sourcepub fn builder() -> RegisteredUserQuickSightConsoleEmbeddingConfigurationBuilder
pub fn builder() -> RegisteredUserQuickSightConsoleEmbeddingConfigurationBuilder
Creates a new builder-style object to manufacture RegisteredUserQuickSightConsoleEmbeddingConfiguration.