#[non_exhaustive]pub struct RegisteredUserEmbeddingExperienceConfiguration {
pub dashboard: Option<RegisteredUserDashboardEmbeddingConfiguration>,
pub quick_sight_console: Option<RegisteredUserQuickSightConsoleEmbeddingConfiguration>,
pub q_search_bar: Option<RegisteredUserQSearchBarEmbeddingConfiguration>,
pub dashboard_visual: Option<RegisteredUserDashboardVisualEmbeddingConfiguration>,
pub generative_qn_a: Option<RegisteredUserGenerativeQnAEmbeddingConfiguration>,
pub quick_chat: Option<RegisteredUserQuickChatEmbeddingConfiguration>,
}Expand description
The type of experience you want to embed. For registered users, you can embed Quick dashboards or the Amazon Quick Sight console.
Exactly one of the experience configurations is required. You can choose Dashboard or QuickSightConsole. You cannot choose more than one experience configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dashboard: Option<RegisteredUserDashboardEmbeddingConfiguration>The configuration details for providing a dashboard embedding experience.
quick_sight_console: Option<RegisteredUserQuickSightConsoleEmbeddingConfiguration>The configuration details for providing each Amazon Quick Sight console embedding experience. This can be used along with custom permissions to restrict access to certain features. For more information, see Customizing Access to the Amazon Quick Sight Console in the Amazon Quick User Guide.
Use GenerateEmbedUrlForRegisteredUser where you want to provide an authoring portal that allows users to create data sources, datasets, analyses, and dashboards. The users who accesses an embedded Amazon Quick Sight console needs to belong to the author or admin security cohort. If you want to restrict permissions to some of these features, add a custom permissions profile to the user with the UpdateUser API operation. Use the RegisterUser API operation to add a new user with a custom permission profile attached. For more information, see the following sections in the Amazon Quick User Guide:
For more information about the high-level steps for embedding and for an interactive demo of the ways you can customize embedding, visit the Amazon Quick Developer Portal.
q_search_bar: Option<RegisteredUserQSearchBarEmbeddingConfiguration>The configuration details for embedding the Q search bar.
For more information about embedding the Q search bar, see Embedding Overview in the Amazon Quick Sight User Guide.
dashboard_visual: Option<RegisteredUserDashboardVisualEmbeddingConfiguration>The type of embedding experience. In this case, Amazon Quick Sight visuals.
generative_qn_a: Option<RegisteredUserGenerativeQnAEmbeddingConfiguration>The configuration details for embedding the Generative Q&A experience.
For more information about embedding the Generative Q&A experience, see Embedding Overview in the Amazon Quick Sight User Guide.
quick_chat: Option<RegisteredUserQuickChatEmbeddingConfiguration>The configuration details for embedding the Quick chat agent.
Implementations
Sourceimpl RegisteredUserEmbeddingExperienceConfiguration
impl RegisteredUserEmbeddingExperienceConfiguration
Sourcepub fn dashboard(
&self,
) -> Option<&RegisteredUserDashboardEmbeddingConfiguration>
pub fn dashboard( &self, ) -> Option<&RegisteredUserDashboardEmbeddingConfiguration>
The configuration details for providing a dashboard embedding experience.
Sourcepub fn quick_sight_console(
&self,
) -> Option<&RegisteredUserQuickSightConsoleEmbeddingConfiguration>
pub fn quick_sight_console( &self, ) -> Option<&RegisteredUserQuickSightConsoleEmbeddingConfiguration>
The configuration details for providing each Amazon Quick Sight console embedding experience. This can be used along with custom permissions to restrict access to certain features. For more information, see Customizing Access to the Amazon Quick Sight Console in the Amazon Quick User Guide.
Use GenerateEmbedUrlForRegisteredUser where you want to provide an authoring portal that allows users to create data sources, datasets, analyses, and dashboards. The users who accesses an embedded Amazon Quick Sight console needs to belong to the author or admin security cohort. If you want to restrict permissions to some of these features, add a custom permissions profile to the user with the UpdateUser API operation. Use the RegisterUser API operation to add a new user with a custom permission profile attached. For more information, see the following sections in the Amazon Quick User Guide:
For more information about the high-level steps for embedding and for an interactive demo of the ways you can customize embedding, visit the Amazon Quick Developer Portal.
Sourcepub fn q_search_bar(
&self,
) -> Option<&RegisteredUserQSearchBarEmbeddingConfiguration>
pub fn q_search_bar( &self, ) -> Option<&RegisteredUserQSearchBarEmbeddingConfiguration>
The configuration details for embedding the Q search bar.
For more information about embedding the Q search bar, see Embedding Overview in the Amazon Quick Sight User Guide.
Sourcepub fn dashboard_visual(
&self,
) -> Option<&RegisteredUserDashboardVisualEmbeddingConfiguration>
pub fn dashboard_visual( &self, ) -> Option<&RegisteredUserDashboardVisualEmbeddingConfiguration>
The type of embedding experience. In this case, Amazon Quick Sight visuals.
Sourcepub fn generative_qn_a(
&self,
) -> Option<&RegisteredUserGenerativeQnAEmbeddingConfiguration>
pub fn generative_qn_a( &self, ) -> Option<&RegisteredUserGenerativeQnAEmbeddingConfiguration>
The configuration details for embedding the Generative Q&A experience.
For more information about embedding the Generative Q&A experience, see Embedding Overview in the Amazon Quick Sight User Guide.
Sourcepub fn quick_chat(
&self,
) -> Option<&RegisteredUserQuickChatEmbeddingConfiguration>
pub fn quick_chat( &self, ) -> Option<&RegisteredUserQuickChatEmbeddingConfiguration>
The configuration details for embedding the Quick chat agent.
Sourceimpl RegisteredUserEmbeddingExperienceConfiguration
impl RegisteredUserEmbeddingExperienceConfiguration
Sourcepub fn builder() -> RegisteredUserEmbeddingExperienceConfigurationBuilder
pub fn builder() -> RegisteredUserEmbeddingExperienceConfigurationBuilder
Creates a new builder-style object to manufacture RegisteredUserEmbeddingExperienceConfiguration.